==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/user/messages/es/profile.php <==
<?php

return [
    '%y Years' => '%y Años',
    '<b>This profile stream is still empty!</b>' => '<b>¡La actividad de este perfil está aún vacía!</b>',
    '<b>This profile stream is still empty</b><br>Be the first and post something...' => '<b>Esta actividad está vacía todavía</b><br />Sé el primero en añadir algo...',
    '<b>Your profile stream is still empty</b><br>Get started and post something...' => '<b>La actividad de tu perfil aún está vacia</b><br />Comienza escribiendo algo...',
    '<strong>About</strong> this user' => '<strong>Sobre</strong> este usuario',
    '<strong>Profile</strong> menu' => 'Menú de <strong>perfil</strong>',
    'About' => 'Acerca de',
    'Allow other selection' => 'Permitir otra selección',
    'Birthday' => 'Cumpleaños',
    'Birthday field options' => 'Opciones del campo Cumpleaños',
    'Checkbox' => 'Caja',
    'Checkbox List' => 'Lista de marcas',
    'Checkbox field options' => 'Opciones del campo de selección',
    'City' => 'Ciudad',
    'Comma separated country codes, e.g. DE,EN,AU' => 'Códigos de país separados por comas, p.ej. DE,EN,AU',
    'Communication' => 'Comunicación',
    'Country' => 'País',
    'Created at' => 'Creado el',
    'Created by' => 'Creado por',
    'Creation date of the user' => 'Fecha de creación del usuario',
    'Custom' => 'Personalizado',
    'Date' => 'Fecha',
    'Date(-time) field options' => 'Opciones del campo Fecha (y hora)',
    'Datetime' => 'Fecha y hora',
    'Default value' => 'Valor por defecto',
    'Description' => 'Descripción',
    'E-Mail' => 'Correo electrónico',
    'E-mail address of the user' => 'Correo electrónico del usuario',
    'Edit account' => 'Editar cuenta',
    'Editable' => 'Editable',
    'Facebook URL' => 'Enlace de Facebook',
    'Fax' => 'Fax',
    'Female' => 'Mujer',
    'Field Type could not be changed!' => '¡El tipo de campo no se puede cambiar!',
    'Fieldtype' => 'Tipo de campo',
    'First name' => 'Nombre',
    'Flickr URL' => 'Enlace de Flickr',
    'Followers' => 'Seguidores',
    'Following' => 'Siguiendo',
    'Friends' => 'Amigos',
    'Gender' => 'Sexo',
    'General' => 'General',
    'Hide age per default' => 'Ocultar edad por defecto',
    'Hide year in profile' => 'Ocultar el año en el perfil',
    'ID' => 'ID',
    'Internal Name' => 'Nombre interno',
    'Internal name already in use!' => '¡El nombre interno ya está en uso!',
    'Internal name could not be changed!' => '¡El nombre interno no se puede cambiar!',
    'Invalid field type!' => '¡Tipo de campo no válido!',
    'Invalid!' => 'Inválido!',
    'LDAP Attribute' => 'Atributo LDAP',
    'Last login date of the user' => 'Fecha de última conexión del usuario',
    'Last name' => 'Apellido',
    'LinkedIn URL' => 'Enlace de LinkedIn',
    'MSN' => 'MSN',
    'Male' => 'Hombre',
    'Markdown' => 'Reducción',
    'Maximum length' => 'Longitud máxima',
    'Maximum value' => 'Valor máximo',
    'Minimum length' => 'Longitud mínima',
    'Minimum value' => 'Valor mínimo',
    'Mobile' => 'Móvil',
    'Module' => 'Módulo',
    'Must contain at least one character.' => 'Tiene que contener al menos un carácter.',
    'MySpace URL' => 'Enlace de MySpace',
    'Number' => 'Número',
    'Number field options' => 'Opciones del campo Número',
    'One option per line. Key=>Value Format (e.g. yes=>Yes)' => 'Una opción por línea. Formato Clave=>Valor (p.ej. si=Sí)',
    'Only alphanumeric characters allowed!' => '¡Solo se permiten caracteres alfanuméricos!',
    'Other:' => 'Otros:',
    'Phone Private' => 'Teléfono privado',
    'Phone Work' => 'Teléfono del trabajo',
    'Please select:' => 'Por favor, elige:',
    'Possible values' => 'Valores posibles',
    'Profile Field Category' => 'Categoría del campo de perfil',
    'Regular Expression: Error message' => 'Expresión regular: Mensaje de error',
    'Regular Expression: Validator' => 'Expresión regular: Validar',
    'Required' => 'Requerido',
    'Searchable' => 'Buscable',
    'Select List' => 'Lista de selección',
    'Select field options' => 'Opciones del campo Lista de selección',
    'Show at registration' => 'Mostrar en el registro',
    'Show date/time picker' => 'Mostrar un selector de fecha/hora',
    'Skype Nickname' => 'Nombre de Skype',
    'Social bookmarks' => 'Marcadores sociales',
    'Sort order' => 'Orden',
    'Spaces' => 'Espacios',
    'State' => 'Estado',
    'Stream' => 'Actividad',
    'Street' => 'Calle',
    'Supported ISO3166 country codes' => 'Códigos de país ISO3166 soportados',
    'Text' => 'Texto',
    'Text Area' => 'Área de texto',
    'Text Field Options' => 'Opciones del campo Texto',
    'Text area field options' => 'Opciones del campo Área de texto',
    'This profile is no longer available!' => '¡Este perfil ya no está disponible!',
    'This user account is not approved yet!' => '¡Esta cuenta de usuario no está aprobada todavía!',
    'This will add an additional input element for custom values' => 'Añade un elemento de entrada adicional para incluir valores personalizados',
    'Title' => 'Título',
    'Translation Category ID' => 'ID de la categoría de traducción',
    'Twitter URL' => 'Enlace de Twitter',
    'Type Config' => 'Configuración de tipo',
    'Updated at' => 'Actualizado el',
    'Updated by' => 'Actualizado por',
    'Url' => 'Web',
    'Use as Directory filter' => 'Utilizar como filtro del Directorio',
    'Username' => 'Nombre de usuario',
    'Validator' => 'Validar',
    'Vimeo URL' => 'Enlace de Vimeo',
    'Visible' => 'Visible',
    'XMPP Jabber Address' => 'Direccción Jabber XMPP',
    'Xing URL' => 'Enlace de Xing',
    'You need to login to view this user profile!' => '¡Necesitas iniciar sesión para ver este perfil de usuario!',
    'YouTube URL' => 'Enlace de YouTube',
    'Zip' => 'Código postal',
    '{attribute} is required!' => 'Se requiere {attribute}!',
    'Link Prefix (e.g. https://, mailto:, tel://)' => '',
];

==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/modules/user/messages/es/profile.php <==
<?php

return [
    '%y Years' => '%y Años',
    '<b>This profile stream is still empty!</b>' => '<b>¡La actividad de este perfil está aún vacía!</b>',
    '<b>This profile stream is still empty</b><br>Be the first and post something...' => '<b>Esta actividad está vacía todavía</b><br />Sé el primero en añadir algo...',
    '<b>Your profile stream is still empty</b><br>Get started and post something...' => '<b>La actividad de tu perfil aún está vacia</b><br />Comienza escribiendo algo...',
    '<strong>About</strong> this user' => '<strong>Sobre</strong> este usuario',
    '<strong>Profile</strong> menu' => 'Menú de <strong>perfil</strong>',
    'About' => 'Acerca de',
    'Allow other selection' => 'Permitir otra selección',
    'Birthday' => 'Cumpleaños',
    'Birthday field options' => 'Opciones del campo Cumpleaños',
    'Checkbox' => 'Caja',
    'Checkbox List' => 'Lista de marcas',
    'Checkbox field options' => 'Opciones del campo de selección',
    'City' => 'Ciudad',
    'Comma separated country codes, e.g. DE,EN,AU' => 'Códigos de país separados por comas, p.ej. DE,EN,AU',
    'Communication' => 'Comunicación',
    'Country' => 'País',
    'Created at' => 'Creado el',
    'Created by' => 'Creado por',
    'Creation date of the user' => 'Fecha de creación del usuario',
    'Date' => 'Fecha',
    'Date(-time) field options' => 'Opciones del campo Fecha (y hora)',
    'Datetime' => 'Fecha y hora',
    'Default value' => 'Valor por defecto',
    'Description' => 'Descripción',
    'Diverse' => 'Diverso',
    'E-Mail' => 'Correo electrónico',
    'E-mail address of the user' => 'Correo electrónico del usuario',
    'Edit account' => 'Editar cuenta',
    'Editable' => 'Editable',
    'Facebook URL' => 'Enlace de Facebook',
    'Fax' => 'Fax',
    'Female' => 'Mujer',
    'Field Type could not be changed!' => '¡El tipo de campo no se puede cambiar!',
    'Fieldtype' => 'Tipo de campo',
    'First name' => 'Nombre',
    'Followers' => 'Seguidores',
    'Following' => 'Siguiendo',
    'Friends' => 'Amigos',
    'Gender' => 'Sexo',
    'General' => 'General',
    'Hide age per default' => 'Ocultar edad por defecto',
    'Hide year in profile' => 'Ocultar el año en el perfil',
    'ID' => 'ID',
    'Instagram URL' => 'URL de Instagram',
    'Internal Name' => 'Nombre interno',
    'Internal name already in use!' => '¡El nombre interno ya está en uso!',
    'Internal name could not be changed!' => '¡El nombre interno no se puede cambiar!',
    'Invalid field type!' => '¡Tipo de campo no válido!',
    'Invalid!' => 'Inválido!',
    'LDAP Attribute' => 'Atributo LDAP',
    'Last login date of the user' => 'Fecha de última conexión del usuario',
    'Last name' => 'Apellido',
    'Link Prefix (e.g. https://, mailto:, tel://)' => 'Prefijo del enlace (p. ej. https://, mailto:, tel://)',
    'LinkedIn URL' => 'Enlace de LinkedIn',
    'Male' => 'Hombre',
    'Markdown' => 'Reducción',
    'Maximum length' => 'Longitud máxima',
    'Maximum value' => 'Valor máximo',
    'Minimum length' => 'Longitud mínima',
    'Minimum value' => 'Valor mínimo',
    'Mobile' => 'Móvil',
    'Module' => 'Módulo',
    'Must contain at least one character.' => 'Tiene que contener al menos un carácter.',
    'Number' => 'Número',
    'Number field options' => 'Opciones del campo Número',
    'One option per line. Key=>Value Format (e.g. yes=>Yes)' => 'Una opción por línea. Formato Clave=>Valor (p.ej. si=Sí)',
    'Only alphanumeric characters allowed!' => '¡Solo se permiten caracteres alfanuméricos!',
    'Other:' => 'Otros:',
    'Phone Private' => 'Teléfono privado',
    'Phone Work' => 'Teléfono del trabajo',
    'Please select:' => 'Por favor, elige:',
    'Possible values' => 'Valores posibles',
    'Profile Field Category' => 'Categoría del campo de perfil',
    'Regular Expression: Error message' => 'Expresión regular: Mensaje de error',
    'Regular Expression: Validator' => 'Expresión regular: Validar',
    'Required' => 'Requerido',
    'Searchable' => 'Buscable',
    'Select List' => 'Lista de selección',
    'Select field options' => 'Opciones del campo Lista de selección',
    'Show at registration' => 'Mostrar en el registro',
    'Show date/time picker' => 'Mostrar un selector de fecha/hora',
    'Social bookmarks' => 'Marcadores sociales',
    'Sort order' => 'Orden',
    'Spaces' => 'Espacios',
    'State' => 'Estado',
    'Stream' => 'Actividad',
    'Street' => 'Calle',
    'Supported ISO3166 country codes' => 'Códigos de país ISO3166 soportados',
    'Text' => 'Texto',
    'Text Area' => 'Área de texto',
    'Text Field Options' => 'Opciones del campo Texto',
    'Text area field options' => 'Opciones del campo Área de texto',
    'This profile is no longer available!' => '¡Este perfil ya no está disponible!',
    'This user account is not approved yet!' => '¡Esta cuenta de usuario no está aprobada todavía!',
    'This will add an additional input element for custom values' => 'Añade un elemento de entrada adicional para incluir valores personalizados',
    'TikTok URL' => 'URL de TikTok',
    'Title' => 'Título',
    'Translation Category ID' => 'ID de la categoría de traducción',
    'Twitter URL' => 'Enlace de Twitter',
    'Type Config' => 'Configuración de tipo',
    'Updated at' => 'Actualizado el',
    'Updated by' => 'Actualizado por',
    'Use as Directory filter' => 'Utilizar como filtro del Directorio',
    'Username' => 'Nombre de usuario',
    'Validator' => 'Validar',
    'Vimeo URL' => 'Enlace de Vimeo',
    'Visible' => 'Visible',
    'Website URL' => 'Web',
    'XMPP Jabber Address' => 'Direccción Jabber XMPP',
    'Xing URL' => 'Enlace de Xing',
    'You need to login to view this user profile!' => '¡Necesitas iniciar sesión para ver este perfil de usuario!',
    'YouTube URL' => 'Enlace de YouTube',
    'Zip' => 'Código postal',
    '{attribute} is required!' => 'Se requiere {attribute}!',
    'Mastodon URL' => '',
];
